% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/strata_and_cluster_rs.R
\name{strata_and_cluster_rs}
\alias{strata_and_cluster_rs}
\title{Stratified and Clustered Random Sampling}
\usage{
strata_and_cluster_rs(strata = strata_var, clusters = clust_var,
  prob = NULL, n = NULL, strata_n = NULL, strata_prob = NULL,
  check_inputs = TRUE, strata_var = NULL, clust_var = NULL)
}
\arguments{
\item{strata}{A vector of length N that indicates which stratum each unit belongs to.}

\item{clusters}{A vector of length N that indicates which cluster each unit belongs to.}

\item{prob}{Use for a design in which either floor(N_clusters_stratum*prob) or ceiling(N_clusters_stratum*prob) clusters are sampled within each stratum. The probability of being sampled is exactly prob because with probability 1-prob, floor(N_clusters_stratum*prob) clusters will be sampled and with probability prob, ceiling(N_clusters_stratum*prob) clusters will be sampled. prob must be a real number between 0 and 1 inclusive. (optional)}

\item{n}{Use for a design in which the scalar n describes the fixed number of units to sample in each stratum. This number does not vary across strata.}

\item{strata_n}{Use for a design in which strata_n describes the number of units to sample within each stratum.}

\item{strata_prob}{Use for a design in which strata_prob describes the probability of being sampled within each stratum. Differs from prob in that the probability of being sampled can vary across strata.}

\item{check_inputs}{logical. Defaults to TRUE.}

\item{strata_var}{deprecated}

\item{clust_var}{deprecated}
}
\value{
A numeric vector of length N that indicates if a unit is sampled (1) or not (0).
}
\description{
A random sampling procedure in which units are sampled as clusters and clusters are nested within strata.
}
\examples{
clusters <- rep(letters, times = 1:26)

strata <- rep(NA, length(clusters))
strata[clusters \%in\% letters[1:5]] <- "stratum_1"
strata[clusters \%in\% letters[6:10]] <- "stratum_2"
strata[clusters \%in\% letters[11:15]] <- "stratum_3"
strata[clusters \%in\% letters[16:20]] <- "stratum_4"
strata[clusters \%in\% letters[21:26]] <- "stratum_5"

table(strata, clusters)

S <- strata_and_cluster_rs(strata = strata,
                          clusters = clusters)

table(S, strata)
table(S, clusters)


S <- strata_and_cluster_rs(clusters = clusters,
                           strata = strata,
                           prob = .5)

table(S, clusters)
table(S, strata)

S <- strata_and_cluster_rs(clusters = clusters,
                           strata = strata,
                           strata_n = c(2, 3, 2, 3, 2))

table(S, clusters)
table(S, strata)

S <- strata_and_cluster_rs(clusters = clusters,
                           strata = strata,
                           strata_prob = c(.1, .2, .3, .4, .5))

table(S, clusters)
table(S, strata)


}
